:tocdepth: 1

#######
Credits
#######
The Maastricht Optimization Toolbox is a model optimization toolbox originally meant for diffusion MRI analysis, but
applicable to any other field. Software development by Robbert Harms, under the
(Phd) supervision of Alard Roebroeck, at Maastricht University.


************
Contributors
************

* Robbert Harms
    - Lead developer

